==> scilab-2.1.1.tar.gz: scilab-2.1.1/routines/xsci/help/help-text4.h <==
"  abcd   - state-space matrices ",
"  arhnk   - Hankel norm approximant ",
"  arl2   - L2 approximation ",
"  balreal   - balanced realization ",
"  calfrq   - frequency response discretization ",
"  canon   - canonical controllable form ",
"  cls2dls   - bilinear transform ",
"  colregul   - removing poles and zeros at infinity ",
"  cont_frm   - transfer to controllable state-space ",
"  cont_mat   - controllability matrix ",
"  contr   - controllability, controllable subspace ",
"  contrss   - controllable part ",
"  csim   - simulation (time response) of linear system ",
"  ctr_gram   - controllability gramian ",
"  des2tf   - descriptor to transfer function conversion ",
"  dscr   -  discretization of linear system ",
"  dsimul   - discrete time response ",
"  dt_ility   - detectability test ",
"   ",
"  equil   - balancing of pair of symmetric matrices ",
"  equil1   - balancing (nonnegative) pair of matrices ",
"  feedback   - feedback operation ",
"  flts   - time response (discrete time, sampled system) ",
"  frep2tf   - frequency response to  transfer function ",
"  freq   - frequency response ",
"  freson   - peak frequencies ",
"  g_margin   - gain margin ",
"  imrep2ss   - impulse response to state-space conversion ",
"  invsyslin   - system inversion ",
"  lin   - linearization ",
"  lqe   - linear quadratic estimator (Kalman Filter) ",
"  lqg   - LQG compensator ",
"  lqg2stan   - LQG to standard problem ",
"  lqr   - LQ compensator (full state) ",
"  ltitr   - discrete time response (state space) ",
"  markp2ss   - Markov parameters to state-space ",
"  minreal   - minimal balanced realization ",
"  minss   - minimal realization ",
"  obs_gram   - observability grammian ",
"  obscont   - observer based controller ",
"  obsv_mat   - observability matrix ",
"  obsvss   - observable part ",
"  p_margin   - phase margin ",
"  pfss   - partial fraction decomposition ",
"  phasemag   - phase magnitude computation ",
"  ppol   - pole placement ",
"  projsl   - linear system projection ",
"  repfreq   - frequency response ",
"  ricc   - Riccati equation  ",
"  rowregul   - removing poles and zeros at infinity ",
"  rtitr   - discrete time response (transfer matrix) ",
"  sm2des   - system matrix to descriptor ",
"  sm2ss   - system matrix to state-space ",
"  specfact   - spectral factor ",
"  ss2des   - (polynomial) state-space to descriptor form ",
"  ss2ss   - state-space to state-space conversion, feedback, injection ",
"  ss2tf   - conversion from state-space to transfer function ",
"  st_ility   - stabilizability test ",
"  svplot   - singular-value sigma-plot ",
"  tf2ss   - transfer to state-space ",
"  time_id   - SISO identification ",
"  trzeros   - transmission zeros and normal rank ",
"  unobs   - unobservable subspace ",
"  zeropen   - zero pencil ",

==> scilab_2.2.orig.tar.gz: scilab-2.2.orig/routines/xsci/help/help-text4.h <==
"  abcd   - state-space matrices ",
"  abinv   -  AB invariant subspace ",
"  arhnk   - Hankel norm approximant ",
"  arl2   - SISO model realization by L2 transfer approximation ",
"  balreal   - balanced realization ",
"  cainv   -  Dual of abinv ",
"  calfrq   - frequency response discretization ",
"  canon   - canonical controllable form ",
"  cls2dls   - bilinear transform ",
"  colregul   - removing poles and zeros at infinity ",
"  cont_frm   - transfer to controllable state-space ",
"  cont_mat   - controllability matrix ",
"  contr   - controllability, controllable subspace ",
"  contrss   - controllable part ",
"  csim   - simulation (time response) of linear system ",
"  ctr_gram   - controllability gramian ",
"  des2tf   - descriptor to transfer function conversion ",
"  dscr   -  discretization of linear system ",
"  dsimul   - discrete time response ",
"  dt_ility   - detectability test ",
"  equil   - balancing of pair of symmetric matrices ",
"  equil1   - balancing (nonnegative) pair of matrices ",
"  feedback   - feedback operation ",
"  flts   - time response (discrete time, sampled system) ",
"  frep2tf   - transfer function realization of a frequency response ",
"  freq   - frequency response ",
"  freson   - peak frequencies ",
"  g_margin   - gain margin ",
"  imrep2ss   - state-space realization of an impulse response  ",
"  invsyslin   - system inversion ",
"  lin   - linearization ",
"  lqe   - linear quadratic estimator (Kalman Filter) ",
"  lqg   - LQG compensator ",
"  lqg2stan   - LQG to standard problem ",
"  lqr   - LQ compensator (full state) ",
"  ltitr   - discrete time response (state space) ",
"  markp2ss   - Markov parameters to state-space ",
"  minreal   - minimal balanced realization ",
"  minss   - minimal realization ",
"  obs_gram   - observability grammian ",
"  obscont   - observer based controller ",
"  observer   - observer design ",
"  obsv_mat   - observability matrix ",
"  obsvss   - observable part ",
"  p_margin   - phase margin ",
"  pfss   - partial fraction decomposition ",
"  phasemag   - phase magnitude computation ",
"  ppol   - pole placement ",
"  projsl   - linear system projection ",
"  repfreq   - frequency response ",
"  ricc   - Riccati equation  ",
"  rowregul   - removing poles and zeros at infinity ",
"  rtitr   - discrete time response (transfer matrix) ",
"  sm2des   - system matrix to descriptor ",
"  sm2ss   - system matrix to state-space ",
"  specfact   - spectral factor ",
"  ss2des   - (polynomial) state-space to descriptor form ",
"  ss2ss   - state-space to state-space conversion, feedback, injection ",
"  ss2tf   - conversion from state-space to transfer function ",
"  st_ility   - stabilizability test ",
"  stabil   - stabilization ",
"  svplot   - singular-value sigma-plot ",
"  tf2ss   - transfer to state-space ",
"  time_id   - SISO least square identification ",
"  trzeros   - transmission zeros and normal rank ",
"  unobs   - unobservable subspace ",
"  zeropen   - zero pencil ",
